# TableauTransformer

ETL tooling for preparing tableau seed data

## Description

This library was built with the intentions of enhancing the experience of data wrangling for tableau.
Tableau can be very particular about the data it reads from.
In addition preparing data to fit the shape for different graphs can be time consuming.
TableauTransformer can be used to hurdle over these two barriers.

## Getting Started

### Dependencies

* pip, python 3.6, pandas, numpy

### Installing

```
pip install tableautransformer
```

### Executing program

* Step-by-step bullets
```
import tableautransformer as tbt
```
## Function Docs

## Help

Any advise for common problems or issues.
```
command to run if program contains helper info
```

## Authors

Contributors names and contact info

* Josh Teixeira  |  jteixeira@cppib.com

## Version History

* 0.0.2
    * Reduced python requirement
* 0.0.1
    * Initial beta release

## License

This project is licensed under the MIT License - see the LICENSE.md file for details